Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(270)

Unified Diff: chrome/browser/autofill/form_structure.h

Issue 11198048: [Autofill] Update the autocomplete types implementation to match the current HTML spec. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Update AutofillFieldTest expectations Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/autofill/form_field.cc ('k') | chrome/browser/autofill/form_structure.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/autofill/form_structure.h
diff --git a/chrome/browser/autofill/form_structure.h b/chrome/browser/autofill/form_structure.h
index fba3c1f5124b2610453bb4c8951dac659ce1336a..39db10927f8a884a26d27c4d6d307c096f465681 100644
--- a/chrome/browser/autofill/form_structure.h
+++ b/chrome/browser/autofill/form_structure.h
@@ -154,13 +154,15 @@ class FormStructure {
bool EncodeFormRequest(EncodeRequestType request_type,
buzz::XmlElement* encompassing_xml_element) const;
- // Classifies each field in |fields_| based upon its |autocompletetype|
- // attribute, if the attribute is available. The association is stored into
- // |map|. Fills |found_attribute| with |true| if the attribute is available
- // (and non-empty) for at least one field. Fills |found_sections| with |true|
- // if the attribute specifies a section for at least one field.
- void ParseAutocompletetypeAttributes(bool* found_attribute,
- bool* found_sections);
+ // Classifies each field in |fields_| based upon its |autocomplete| attribute,
+ // if the attribute is available. The association is stored into the field's
+ // |heuristic_type|.
+ // Fills |found_types| with |true| if the attribute is available and neither
+ // empty nor set to the special values "on" or "off" for at least one field.
+ // Fills |found_sections| with |true| if the attribute specifies a section for
+ // at least one field.
+ void ParseFieldTypesFromAutocompleteAttributes(bool* found_types,
+ bool* found_sections);
// Classifies each field in |fields_| into a logical section.
// Sections are identified by the heuristic that a logical section should not
« no previous file with comments | « chrome/browser/autofill/form_field.cc ('k') | chrome/browser/autofill/form_structure.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698